@@ -1,4 +1,4 @@
-/* Copyright (c) 2005-2006 DN-Systems GmbH http://rfdump.org
+/* Copyright (c) 2005-2007 DN-Systems GmbH http://rfdump.org
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA */
 
-/* $Header: /anoncvs/rfdump/src/acg.c,v 1.14 2006/07/16 16:15:03 dirk Exp $ */
+/* $Header: /anoncvs/rfdump/src/acg.c,v 1.16 2007/10/26 21:00:37 dirk Exp $ */
 
 #include <ctype.h>
 #include <errno.h>
@@ -194,7 +194,7 @@ int acg_printinfo_dual_2_2(int fd)
     case 4: fprintf(stderr, "115200\n"); break;
     case 5: fprintf(stderr, "230400\n"); break;
     case 6: fprintf(stderr, "460800\n"); break;
-    default: fprintf(stderr, "unknown\n"); break;
+    default: fprintf(stderr, "unknown: %i\n", e.baud_rate & 7); break;
     }
 
   fprintf(stderr, "  Command Guard Time: %02X = %.2fus\n", e.command_guard_time, 37.8f*e.command_guard_time);
@@ -436,7 +436,7 @@ int acg_printinfo_multiiso_1_0(int fd)
     case 4: fprintf(stderr, "115200\n"); break;
     case 5: fprintf(stderr, "230400\n"); break;
     case 6: fprintf(stderr, "460800\n"); break;
-    default: fprintf(stderr, "unknown\n"); break;
+    default: fprintf(stderr, "unknown: %i\n", e.baud_rate & 7); break;
     }
 
   fprintf(stderr, "  Command Guard Time: %02X = %.2fus\n", e.command_guard_time, 37.8f*e.command_guard_time);
@@ -648,7 +648,7 @@ int acg_printinfo_iso_0_9(int fd)
     case 1: fprintf(stderr, "19200\n"); break;
     case 2: fprintf(stderr, "38400\n"); break;
     case 3: fprintf(stderr, "57600\n"); break;
-    default: fprintf(stderr, "unknown\n"); break;
+    default: fprintf(stderr, "unknown: %i\n", e.baud_rate & 7); break;
     }
 
   fprintf(stderr, "  binary watchdog timer: %02X\n", e.binary_watchdog_timer);
@@ -745,3 +745,222 @@ int acg_setup_iso_0_9(int fd)
   char *str="setup for rfdump";
   return acg_writeconfig(fd, (unsigned char*)str, 0xE0, 0xE0+strlen(str), NULL);
 }
+
+/***************************************************************************/
+
+#pragma pack(push, 1)
+struct eeprom_lfx_1_0
+{
+  char device_id[5];		/* 00-04 */
+  char admin_data[5];		/* 05-09 */
+  unsigned char station_id;	/* 0A */
+
+  //todo
+  union {
+    unsigned char pcon;		/* 0B */
+    struct {
+      unsigned auto_start : 1;
+      unsigned protocol : 1;
+      unsigned unused_1 : 1;
+      unsigned lock_mode : 1;
+      unsigned led : 1;
+      unsigned single_shot : 1;
+      unsigned page_read : 1;
+      unsigned unused_2 : 1;
+    };
+  };
+
+  unsigned char baud_rate;	/* 0C */
+  unsigned char rfu1; /* 0D */
+
+  //todo
+  union {
+    unsigned char operation_mode; /* 0E */
+    struct {
+      unsigned opmode_em4x02 : 1;
+      unsigned opmode_em4x05 : 1;
+      unsigned opmode_em4x50 : 1;
+      unsigned opmode_hitag1 : 1;
+      unsigned opmode_hitag2 : 1;
+      unsigned opmode_q5 : 1;
+      unsigned opmode_ti : 1;
+      // rfu : 1
+    };
+  };
+
+  unsigned char timeout_value;	/* 0F */
+  unsigned char pcon2;		/* 10 */
+  unsigned char page_start;	/* 11 */
+  unsigned char page_num;	/* 12 */
+
+  unsigned char rfu2; /* 13 */
+
+  unsigned char reset_off_time; /* 14 */
+  unsigned char reset_recovery_time; /* 15 */
+
+  unsigned char em4x02_settings; /* 16 */
+  unsigned char em4x05_settings; /* 17 */
+  unsigned char em4x50_settings; /* 18 */
+  unsigned char hitag1_settings; /* 19 */
+  unsigned char hitag2_settings; /* 1a */
+  unsigned char q5_settings; /* 1b */
+};
+#pragma pack(pop)
+
+int acg_setup_lfx_1_0(int fd)
+{
+  fprintf(stderr, "Setup ACG LFX 1.0\n");
+
+  struct eeprom_lfx_1_0 e;
+  unsigned char *p=(unsigned char*)&e;
+  if(acg_readconfig(fd, p, 0, sizeof(e)) < 0)
+    {
+      fprintf(stderr, "could not read eeprom config\n");
+      return -1;
+    }
+
+  e.station_id=1;
+
+  e.auto_start=0;
+  e.protocol=0;
+  e.lock_mode=0;
+  e.led=0;
+  e.single_shot=0;
+  e.page_read=0;
+
+  //e.baud_rate=0;
+
+  e.opmode_em4x02=1;
+  e.opmode_em4x05=1;
+  e.opmode_em4x50=1;
+  e.opmode_hitag1=1;
+  e.opmode_hitag2=1;
+  e.opmode_q5=1;
+  e.opmode_ti=1;
+
+  e.timeout_value=0x0A;
+  e.pcon2=0;
+  e.page_start=0;
+  e.page_num=1;
+
+  e.reset_off_time=0xA;
+  e.reset_recovery_time=0xA;
+  e.em4x02_settings=0x84;
+  e.em4x05_settings=0x84;
+  e.em4x50_settings=0x84;
+  e.hitag1_settings=0x84;
+  e.hitag2_settings=0x84;
+  e.q5_settings=0x84;
+
+  int skiplist[]={0xD,0x13,-1};
+  if(acg_writeconfig(fd, p+0x0A, 0x0A, sizeof(e), skiplist) < 0)
+    {
+      fprintf(stderr, "error while writing reader config\n");
+      return -1;
+    }
+
+  char *str="setup for rfdump";
+  return acg_writeconfig(fd, (unsigned char*)str, 0xE0, 0xE0+strlen(str), NULL);
+}
+
+int acg_printinfo_lfx_1_0(int fd)
+{
+  struct eeprom_lfx_1_0 e;
+  if(acg_readconfig(fd, (unsigned char*)&e, 0, sizeof(e)) < 0)
+    {
+      fprintf(stderr, "could not read eeprom config\n");
+      return -1;
+    }
+
+  fprintf(stderr, "ACG LFX 1.0 EEPROM contents:\n");
+  fprintf(stderr, "  device ID: %02X%02X%02X%02X%02X\n", e.device_id[0], e.device_id[1], e.device_id[2], e.device_id[3], e.device_id[4]);
+  fprintf(stderr, "  admin data: %02X%02X%02X%02X%02X\n", e.admin_data[0], e.admin_data[1], e.admin_data[2], e.admin_data[3], e.admin_data[4]);
+  fprintf(stderr, "  Station ID: %02X\n", e.station_id);
+
+  fprintf(stderr, "  PCON1: %02X\n", e.pcon);
+  fprintf(stderr, "    auto start: %i\n", e.auto_start);
+  fprintf(stderr, "    protocol: %i = %s\n", e.protocol, e.protocol?"binary":"ASCII");
+  fprintf(stderr, "    lock mode: %i\n", e.lock_mode);
+  fprintf(stderr, "    led: %i\n", e.led);
+  fprintf(stderr, "    single shot: %i\n", e.single_shot);
+  fprintf(stderr, "    page read: %i\n", e.page_read);
+
+  fprintf(stderr, "  Baud rate: %02X = ", e.baud_rate);
+  switch(e.baud_rate & 3)
+    {
+    case 0: fprintf(stderr, "9600\n"); break;
+    case 1: fprintf(stderr, "19200\n"); break;
+    case 2: fprintf(stderr, "38400\n"); break;
+    case 3: fprintf(stderr, "57600\n"); break;
+    case 4: fprintf(stderr, "115200\n"); break;
+    default: fprintf(stderr, "unknown: %i\n", e.baud_rate & 7); break;
+    }
+
+  fprintf(stderr, "  Operation Mode: %02X = ", e.operation_mode);
+  if(e.opmode_em4x02)
+    fprintf(stderr, "EM4x02 ");
+  if(e.opmode_em4x05)
+    fprintf(stderr, "EM4x05 ");
+  if(e.opmode_em4x50)
+    fprintf(stderr, "EM4x50 ");
+  if(e.opmode_hitag1)
+    fprintf(stderr, "HITAG1 ");
+  if(e.opmode_hitag2)
+    fprintf(stderr, "HITAG2 ");
+  if(e.opmode_q5)
+    fprintf(stderr, "Q5 ");
+  if(e.opmode_ti)
+    fprintf(stderr, "TI-RFID ");
+  fprintf(stderr, "\n");
+
+  fprintf(stderr, "  time-out value: %02X = %ims\n", e.timeout_value, e.timeout_value*100);
+
+  fprintf(stderr, "  PCON2: %02X\n", e.pcon2);
+  if(e.pcon2 & 1)
+    fprintf(stderr, "    Compatibility Mode\n");
+  if(e.pcon2 & 2)
+    fprintf(stderr, "    Disable startup message\n");
+  if(e.pcon2 & 4)
+    fprintf(stderr, "    Enable binary frame v2\n");
+  if(e.pcon2 & 8)
+    fprintf(stderr, "    Noisy Environment\n");
+  if(e.pcon2 & 16)
+    fprintf(stderr, "    Safe Mode\n");
+
+  fprintf(stderr, "  Page Start: %02X\n", e.page_start);
+  fprintf(stderr, "  Page Number: %02X\n", e.page_num);
+  fprintf(stderr, "  Reset Off Time: %ims\n", e.reset_off_time);
+  fprintf(stderr, "  Reset Recovery Time: %ims\n", e.reset_recovery_time);
+
+  fprintf(stderr, "  Tag Setting EM4x02: %02X\n", e.em4x02_settings);
+  fprintf(stderr, "  Tag Setting EM4x05: %02X\n", e.em4x05_settings);
+  fprintf(stderr, "  Tag Setting EM4x50: %02X\n", e.em4x50_settings);
+  fprintf(stderr, "  Tag Setting HITAG1: %02X\n", e.hitag1_settings);
+  fprintf(stderr, "  Tag Setting HITAG2: %02X\n", e.hitag2_settings);
+  fprintf(stderr, "  Tag Setting Q5:     %02X\n", e.q5_settings);
+
+  unsigned char userdata[0xF0-0x20];
+  if(acg_readconfig(fd, userdata, 0x20, 0xF0) == 0)
+    {
+      int i;
+      fprintf(stderr, "  user data:\n");
+      for(i=0; i<sizeof(userdata);)
+	{
+	  int j;
+	  fprintf(stderr, "    %02X: ", i+0x20);
+
+	  for(j=0; j!=16 && i<sizeof(userdata); ++j, ++i)
+	    fprintf(stderr, "%02X ", userdata[i]);
+
+	  fprintf(stderr, " - ");
+	  i-=j;
+
+	  for(j=0; j!=16 && i<sizeof(userdata); ++j, ++i)
+	    fprintf(stderr, "%c", isprint(userdata[i])?userdata[i]:'.');
+
+	  fprintf(stderr, "\n");
+	}
+    }
+
+  return 0;
+}
