@@ -1,4 +1,4 @@
-/* Copyright (c) 2005-2006 DN-Systems GmbH http://rfdump.org
+/* Copyright (c) 2005-2007 DN-Systems GmbH http://rfdump.org
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA */
 
-/* $Header: /anoncvs/rfdump/src/acg.h,v 1.6 2006/07/16 16:15:03 dirk Exp $ */
+/* $Header: /anoncvs/rfdump/src/acg.h,v 1.9 2007/10/31 21:59:27 dirk Exp $ */
 
 #ifndef ACG__H
 #define ACG__H
@@ -28,4 +28,7 @@ int acg_setup_dual_2_2(int fd);
 int acg_printinfo_multiiso_1_0(int fd);
 int acg_setup_multiiso_1_0(int fd);
 
+int acg_printinfo_lfx_1_0(int fd);
+int acg_setup_lfx_1_0(int fd);
+
 #endif
