@@ -1,4 +1,4 @@
-/* Copyright (c) 2005-2006 DN-Systems GmbH http://rfdump.org
+/* Copyright (c) 2005-2007 DN-Systems GmbH http://rfdump.org
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA */
 
-/* $Header: /anoncvs/rfdump/src/main.c,v 1.48 2006/07/24 11:20:21 dirk Exp $ */
+/* $Header: /anoncvs/rfdump/src/main.c,v 1.52 2007/10/31 21:59:27 dirk Exp $ */
 
 #include <ctype.h>
 #include <errno.h>
@@ -202,7 +202,7 @@ static void cell_edited_callback (GtkCellRendererText *cell, gchar *path_string,
 	{
 	  int i;
 
-	  gchar *tmp_new_text = (gchar*)malloc((NUM_HEX_COLS*tag.pageSize)+1); /* bug: this memory is lost */
+	  gchar *tmp_new_text = (gchar*)g_malloc((NUM_HEX_COLS*tag.pageSize)+1); /* bug: this memory is lost */
 	  strcpy(tmp_new_text, new_text);
 
 	  for (i=0; i<(NUM_HEX_COLS*tag.pageSize)-strlen(new_text); i++)
@@ -221,7 +221,7 @@ static void cell_edited_callback (GtkCellRendererText *cell, gchar *path_string,
 	}
       else if ((strlen(new_text)<2*tag.pageSize))
 	{
-	  gchar *tmp_new_text = (gchar*)malloc((2*tag.pageSize)+1);	/* bug: this memory is lost */
+	  gchar *tmp_new_text = (gchar*)g_malloc((2*tag.pageSize)+1);	/* bug: this memory is lost */
 	  strcpy(tmp_new_text, new_text);
 
 	  for (i=0; i<(2*tag.pageSize)-strlen(new_text); i++)
@@ -275,23 +275,24 @@ static void cell_edited_callback (GtkCellRendererText *cell, gchar *path_string,
   /* ASCII editor */
   else if (column_number == COL_ASCII)
     {
-      char page[17];
+      const int pageLen=tag.pageSize*2*NUM_HEX_COLS + 10;
+      char *page=g_malloc(pageLen);
       int hexCol = 1;
       unsigned char *new_text_u=(unsigned char*)new_text;
 
       page[0] = '\0';
 
+      const int S=strlen(new_text);
       int i;
-      for (i=0; i<strlen(new_text); i++)
+      for (i=0; i<S; i++)
 	{
-	  char pageByte[3];
+	  char pageByte[sizeof(int64_t)+1];
 	  SNPRINTF(pageByte, sizeof(pageByte), "%02X", new_text_u[i]);
 	  strcat(page, pageByte);
 
 	  if ((i+1)%tag.pageSize == 0)
 	    {
-	      gchar *hexValue = (gchar*)malloc(sizeof(page)+1);
-	      strcpy(hexValue, page);
+	      gchar *hexValue = g_strdup(page);
 
 	      rfidWritePage(fd, (row_number*NUM_HEX_COLS)+(int)(i/tag.pageSize), page);
 	      page[0] = '\0';
@@ -303,6 +304,7 @@ static void cell_edited_callback (GtkCellRendererText *cell, gchar *path_string,
 	      hexCol++;
 	    }
 	}
+      g_free(page);
     }
   else
     error_dialog("B: unknown table col");
@@ -340,7 +342,7 @@ void setup_table()
       char *row[NUM_COLS];
       row[0] = g_strdup_printf("%02X",(int)k*NUM_HEX_COLS);
 
-      row[COL_ASCII] = (char*)malloc(255+1);
+      row[COL_ASCII] = (char*)g_malloc(255+1);
       *(row[COL_ASCII]) = '\0';
 
       int i;
@@ -679,6 +681,23 @@ int main (int argc, char *argv[])
   gtk_set_locale ();
   gtk_init (&argc, &argv);
 
+  /* check if gtk library will work */
+  gchar *gtk_err = gtk_check_version(GTK_MAJOR_VERSION, GTK_MINOR_VERSION, GTK_MICRO_VERSION);
+  if(gtk_err)
+    {
+      fprintf(stderr, "%s\n", gtk_err);
+      exit(EXIT_FAILURE);
+    }
+  else
+    {
+#ifdef DEBUG
+      printf("compiled with gtk+-%i.%i.%i, dynamically linked to gtk+-%i.%i.%i\n",
+	     GTK_MAJOR_VERSION, GTK_MINOR_VERSION, GTK_MICRO_VERSION,
+	     gtk_major_version, gtk_minor_version, gtk_micro_version
+	     );
+#endif
+    }
+
   /* read preferences */
   const char *config_dir=g_get_user_config_dir();
   g_mkdir(config_dir, 0600);
@@ -690,7 +709,7 @@ int main (int argc, char *argv[])
   if(!g_key_file_load_from_file(prefs, PREFS_FN, G_KEY_FILE_KEEP_COMMENTS|G_KEY_FILE_KEEP_TRANSLATIONS, &err))
     {
       fprintf(stderr, "could not load preferences %s : %s\n", PREFS_FN, err?err->message:"");
-      g_key_file_set_comment(prefs, NULL, NULL, " Preferences for RFDump 1.4", &err);
+      g_key_file_set_comment(prefs, NULL, NULL, " Preferences for RFDump " VERSION, &err);
     }
   else
     fprintf(stderr, "using preferences in %s\n", PREFS_FN);
@@ -855,5 +874,5 @@ int main (int argc, char *argv[])
   /* Now the model will be destroyed when the tree view is destroyed */
 
   gtk_main();
-  return 0;
+  return EXIT_SUCCESS;
 }
