@@ -1,4 +1,4 @@
-/* Copyright (c) 2005-2006 DN-Systems GmbH http://rfdump.org
+/* Copyright (c) 2005-2007 DN-Systems GmbH http://rfdump.org
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA */
 
-/* $Header: /anoncvs/rfdump/src/rfid.c,v 1.37 2006/07/24 11:24:39 dirk Exp $ */
+/* $Header: /anoncvs/rfdump/src/rfid.c,v 1.43 2007/10/31 21:59:27 dirk Exp $ */
 
 #include <ctype.h>
 #include <errno.h>
@@ -34,6 +34,8 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA */
 #include "rfid.h"
 #include "tools.h"
 
+int tcp_connect(const char *host, const char *port);
+
 char* RFID_CMD_RESET="x";
 char* RFID_CMD_SELECT="s";
 char* RFID_CMD_READ_PAGE="r";
@@ -87,14 +89,22 @@ static struct termios oldt, curt;
 static char *readerdevice;
 void serial_cleanup()
 {
-  if(fd>=0)
+  if(isatty(fd))
     {
       tcflush(fd, TCIOFLUSH);
       tcsetattr(fd, TCSANOW, &oldt);
+    }
+
+  if(fd>=0)
+    {
       close(fd);
       fd=-1;
     }
-  unlink(lck); lck[0]=0;
+
+  /* cleanup lockfile */
+  if(lck[0])
+    unlink(lck);
+  lck[0]=0;
 }
 
 int rfidConnectReader(char *readerdevice_, int baudrate)
@@ -106,6 +116,16 @@ int rfidConnectReader(char *readerdevice_, int baudrate)
 
   serial_cleanup();
 
+  /* check for network device */
+  {
+    char *port=strchr(readerdevice, ':');
+    if(port)
+      {
+	*port++=0;
+	return fd=tcp_connect(readerdevice,port);
+      }
+  }
+
   /* check lockfile */
   {
     int pos=strlen(readerdevice)-1;
@@ -159,7 +179,7 @@ int rfidConnectReader(char *readerdevice_, int baudrate)
     }
   if(br<0)
     {
-      fprintf(stderr, "unknown baud rate %i == %08X\n", baudrate, baudrate);
+      fprintf(stderr, "unknown baud rate %i == 0x%08X\n", baudrate, baudrate);
       return -1;
     }
   fprintf(stderr, "using serial device %s %i baud\n", readerdevice, br);
@@ -427,9 +447,24 @@ static int readpage_std(int fd, int pageNo, char *page, int pagesize)
   //fprintf(stderr, "readpage_std(%02X):%s\n", pageNo, page);
 
   const int len=strlen(page);
-  if(len == 1 && page[0]=='F')
+  if(len <= 0)
     {
-      fprintf(stderr, "readpage_std(%02X):%s:\n", pageNo, page);
+      fprintf(stderr, "readpage_std(%02X): no result\n", pageNo);
+      return 0;
+    }
+  if(len == 1)
+    {
+      const char *errstr="unknown error";
+      switch(page[0])
+	{
+	case 'C': errstr="CRC Error"; break;
+	case 'F': errstr="Read Failure"; break;
+	case 'N': errstr="No tag in field"; break;
+	case 'O': errstr="Operation mode"; break;
+	case 'R': errstr="Page out of Range"; break;
+	case 'X': errstr="Permission denied"; break;
+	}
+      fprintf(stderr, "readpage_std(%02X):%s:%s\n", pageNo, errstr, page);
       return 0;
     }
   if(len/2 != tag.pageSize)
@@ -759,6 +794,15 @@ int rfidReset(int fd)
 	}
       return 0;
     }
+  if(!strcmp(rfidCmd, "LFX 1.0"))
+    {
+      RFID_CMD_READ_PAGE="rb";
+      RFID_CMD_WRITE_PAGE="wb";
+      RFID_CMD_LOGIN="l";
+      rfidReaderSetup=acg_setup_lfx_1_0;
+      rfidReaderInfo=acg_printinfo_lfx_1_0;
+      return 0;
+    }
 
   fprintf(stderr, "unknown reader\n");
   return -1;
